@@ -5,4 +5,4 @@ version = __version__
 
 from ._decorator import *
 from ._expression import *
-from ._sample import *
+from ._sample import sample
