@@ -153,6 +153,8 @@ class Expression:
 
         tree.map_structure(freeze_aux, self.__dict__)
 
+        return self
+
     def evaluate_children(self):
 
         # propagate the evaluation
@@ -172,6 +174,11 @@ class Expression:
         raise NotImplementedError
 
     def variables(self):
+        """Retrieve all the ``VarExpression`` of the ``Expression``-tree.
+
+        Returns:
+            (dict): a dictionnary where keys are variable ``id`` and values are ``VarExpression`` instances.
+        """
         memo = {}
 
         def choice_aux(o):
@@ -188,6 +195,9 @@ class Expression:
 
         tree.map_structure(choice_aux, self.__dict__)
 
+        if isinstance(self, VarExpression):
+            memo[self.id] = self
+
         return memo
 
     def __copy__(self):
@@ -428,7 +438,10 @@ class ObjectExpression(Expression):
             )
 
     def __repr__(self):
-        return self._obj.__repr__()
+        try:
+            return self._obj.__repr__()
+        except:
+            return str(self._obj)
 
     def evaluate(self):
         self.evaluate_children()
@@ -508,6 +521,7 @@ class List(VarExpression):
         super().__init__(name=name)
         self._values = list(values)
         self._ordered = ordered
+        self._dist = (scipy.stats.randint, {"low": 0, "high": self._length()})
 
     def __repr__(self) -> str:
         # return empty string notation if there aren't any values
@@ -548,7 +562,7 @@ class List(VarExpression):
 
     def freeze(self, choice: dict):
         # obtain the index of intended frozen choice
-        idx = choice[self.id]
+        idx = int(choice[self.id])
 
         # obtain value of a single item
         self.value = self._getitem(idx)
@@ -562,57 +576,6 @@ class List(VarExpression):
             if isinstance(self.value, Expression):
                 self.value.freeze(choice)
 
-    # def _sample(self, size=None, rng=None, memo=None):
-
-    #     if self._k is None:  # "replace" is ignored (only 1 sample is drawn)
-
-    #         # equivalent to constant 0
-    #         if self._invariant:
-    #             idx = np.zeros((size,)) if size else 0
-
-    #         # equivalent to categorical of len(values)
-    #         else:
-    #             idx = rng.choice(self._length(), size=size)
-
-    #     else:  # k >= 1
-
-    #         # equivalent to constant k so "replace" is ignored
-    #         if self._invariant:
-    #             if isinstance(self._k, VarExpression):
-    #                 idx = self._k.sample(size, rng, memo)
-    #             else:
-    #                 idx = np.full((size,), self._k)
-
-    #         # k Categorical of len(values)
-    #         else:
-
-    #             if isinstance(self._k, VarExpression):
-    #                 sample_size = self._k.sample(size, rng, memo)
-
-    #                 if size:  # sample size is an array
-    #                     idx = [
-    #                         rng.choice(
-    #                             self._length(),
-    #                             size=sample_size[i],
-    #                             replace=self._replace,
-    #                         ).tolist()
-    #                         for i in range(size)
-    #                     ]
-    #                 else:  # sample size is a scalar
-    #                     idx = rng.choice(
-    #                         self._length(),
-    #                         size=sample_size,
-    #                         replace=self._replace,
-    #                     )
-    #             else:  # self._k is and int
-    #                 idx = rng.choice(
-    #                     self._length(),
-    #                     size=self._k,
-    #                     replace=self._replace,
-    #                 )
-
-    #     return idx
-
     def child_choices(self):
         memo = {}
 
@@ -648,7 +611,7 @@ class Int(VarExpression):
         super().__init__(name=name)
         self._low = low
         self._high = high
-        self._dist = scipy.stats.randint  # Default Distribution
+        self._dist = (scipy.stats.randint, {"low": self._low, "high": self._high + 1})
 
     def __repr__(self) -> str:
         if not (self.value is None):
@@ -672,23 +635,7 @@ class Int(VarExpression):
                 raise ValueError(
                     f"choice for variable {self} should be between [{self._low}, {self._high}] but is {choice}"
                 )
-        self.value = choice
-
-    def _sample(self, size=None, rng=None, memo=None):
-
-        low = (
-            self._low.sample(size=size, rng=rng, memo=memo)
-            if isinstance(self._low, VarExpression)
-            else self._low
-        )
-        high = (
-            self._high.sample(size=size, rng=rng, memo=memo)
-            if isinstance(self._high, VarExpression)
-            else self._high
-        )
-
-        return self._dist.rvs(low, high+1, size=size, random_state=rng)
-
+        self.value = int(choice)
 
 class Float(VarExpression):
     """Defines a continuous variable.
@@ -702,7 +649,7 @@ class Float(VarExpression):
         super().__init__(name=name)
         self._low = low
         self._high = high
-        self._dist = scipy.stats.uniform
+        self._dist = (scipy.stats.uniform, {"loc": self._low, "scale": self._high - self._low})
 
     def __repr__(self) -> str:
         if not (self.value is None):
@@ -726,19 +673,6 @@ class Float(VarExpression):
                 raise ValueError(
                     f"choice for variable {self} should be between [{self._low}, {self._high}] but is {choice}"
                 )
-        self.value = choice
+        self.value = float(choice)
 
-    def _sample(self, size=None, rng=None, memo=None):
 
-        low = (
-            self._low.sample(size=size, rng=rng, memo=memo)
-            if isinstance(self._low, VarExpression)
-            else self._low
-        )
-        high = (
-            self._high.sample(size=size, rng=rng, memo=memo)
-            if isinstance(self._high, VarExpression)
-            else self._high
-        )
-
-        return self._dist.rvs(loc=low, scale=high - low, size=size, random_state=rng)
